@@ -1,7 +1,7 @@
 import pytest
-from Utilities.log_handler import Logger
-from Utilities.read_properties import ReadConfig
-from Utilities.web_driver_helper import WebDriverHelper
+from src.Utilities.log_handler import Logger
+from src.Utilities.read_properties import ReadConfig
+from src.Utilities.web_driver_helper import WebDriverHelper
 
 
 @pytest.mark.usefixtures("session_setup")
